<div class="selection-overlay {{ hover_selection_css_class }} {{ overlay_selector_css_class }}">
    <div class="checkbox">
        <span class="listing-icon-check-empty unselected-icon"></span>
        <span class="listing-icon-check-2 selected-icon"></span>
    </div>
</div>