{% load django_listing %}
<div class="filters-layout-advanced"{% if not filters.show_advanced %} style="display: none"{% endif %}>
    {% include "django_listing/default/filters_form_fields.html" with layout=filters.form_layout_advanced %}
</div>